pub struct ShapedBuffer { /* private fields */ }Expand description
A buffer of shaped and positioned glyphs. This is the final output of a text shaping operation.
Implementations
Sourceimpl ShapedBuffer
impl ShapedBuffer
Sourcepub fn new(
glyphs: Vec<ShapedGlyph>,
lines: Vec<LineInfo>,
width: f32,
height: f32,
) -> Self
pub fn new( glyphs: Vec<ShapedGlyph>, lines: Vec<LineInfo>, width: f32, height: f32, ) -> Self
Creates a new empty ShapedBuffer.
Sourcepub fn glyphs(&self) -> &[ShapedGlyph]
pub fn glyphs(&self) -> &[ShapedGlyph]
Returns the list of shaped glyphs in this buffer.
Sourcepub fn content_size(&self) -> (f32, f32)
pub fn content_size(&self) -> (f32, f32)
Returns the logical width and height of the text content itself (no padding).
Sourcepub fn outer_size(&self, padding: &Padding) -> (f32, f32)
pub fn outer_size(&self, padding: &Padding) -> (f32, f32)
Returns the visual width and height including the provided padding.
Sourcepub fn size(&self) -> (f32, f32)
pub fn size(&self) -> (f32, f32)
Returns the logical (width, height) used during the last shaping pass.
This is an alias for content_size().